summaryrefslogtreecommitdiff
path: root/src/connection.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/connection.h')
-rw-r--r--src/connection.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/src/connection.h b/src/connection.h
index 3fc5a70..a110ea2 100644
--- a/src/connection.h
+++ b/src/connection.h
@@ -70,9 +70,10 @@ typedef struct
pysqlite_Cache* statement_cache;
/* Lists of weak references to statements and cursors used within this connection */
PyObject* statements;
PyObject* cursors;
+ PyObject* blobs;
/* Counters for how many statements/cursors were created in the connection. May be
* reset to 0 at certain intervals */
@@ -70,9 +70,10 @@ typedef struct
pysqlite_Cache* statement_cache;
- /* Lists of weak references to statements and cursors used within this connection */
+ /* Lists of weak references to statements, blobs and cursors used within this connection */
PyObject* statements;
PyObject* cursors;